from setuptools import setup, find_packages

setup(
    name='PassportSDK',
    version='0.0.7',
    description=(
      'SDK of passport-micro-service'
    ),
    author='NoahWang',
    author_email='234082230@qq.com',
    maintainer='noahwang',
    maintainer_email='234082230@qq.com',
    license='',
    packages=[
        'passportsdk'
    ],
    include_package_data=True,
    zip_safe=False
)
